@@ -517,8 +517,9 @@ impl App {
 
             self = match msg {
                 ExplorePwd => self.explore_pwd(),
-                ExploreParentsAsync => self.explore_parents_async(),
                 ExplorePwdAsync => self.explore_pwd_async(),
+                ExploreParentsAsync => self.explore_parents_async(),
+                TryCompletePath => self.try_complete_path(),
                 Refresh => self.refresh(),
                 ClearScreen => self.clear_screen(),
                 FocusFirst => self.focus_first(true),
@@ -772,6 +773,18 @@ impl App {
         Ok(self)
     }
 
+    fn try_complete_path(self) -> Result<Self> {
+        match self.input.buffer.as_ref().map(|b| b.value()) {
+            None => Ok(self),
+            Some("") => Ok(self),
+            Some(p) => match explorer::try_complete_path(&self.pwd, p) {
+                Ok(Some(completed_path)) => self.set_input_buffer(completed_path),
+                Ok(None) => Ok(self),
+                Err(e) => self.log_error(e.to_string()),
+            },
+        }
+    }
+
     fn refresh(mut self) -> Result<Self> {
         self.msg_out.push_back(MsgOut::Refresh);
         Ok(self)
@@ -1849,7 +1862,12 @@ impl App {
             .unwrap_or_else(|| self.focused_node().map(|n| n.absolute_path.clone()));
 
         self.explorer_config.searcher = Some(NodeSearcherApplicable::new(
-            pattern, rf, algorithm, unordered,
+            pattern,
+            rf,
+            algorithm,
+            unordered,
+            self.config.general.search.exact_mode,
+            self.config.general.search.rank_criteria.clone(),
         ));
         Ok(self)
     }
