@@ -42,11 +42,10 @@ fn parse_version(version: &str) -> Result<(u16, u16, u16, Option<u16>)> {
 
 /// Check the config version and notify users.
 pub fn check_version(version: &str, path: &str) -> Result<()> {
-    // Until we're v1, let's ignore major versions
     let (rmajor, rminor, rbugfix, rbeta) = parse_version(VERSION)?;
     let (smajor, sminor, sbugfix, sbeta) = parse_version(version)?;
 
-    if rmajor == smajor && rminor == sminor && rbugfix >= sbugfix && rbeta == sbeta {
+    if rmajor == smajor && rminor >= sminor && rbugfix >= sbugfix && rbeta == sbeta {
         Ok(())
     } else {
         bail!(
@@ -153,24 +152,24 @@ mod tests {
         assert!(check_version(VERSION, "foo path").is_ok());
 
         // Current release if OK
-        assert!(check_version("1.0.0", "foo path").is_ok());
+        assert!(check_version("1.0.1", "foo path").is_ok());
 
         // Prev major release is ERR
-        assert!(check_version("0.20.0", "foo path").is_err());
+        assert!(check_version("0.20.1", "foo path").is_err());
 
-        // Prev minor release is ERR (Change when we get to v1)
-        // assert!(check_version("1.-1.0", "foo path").is_err());
+        // Prev minor release is ERR
+        assert!(check_version("1.-1.0", "foo path").is_err());
 
         // Prev bugfix release is OK
-        // assert!(check_version("1.0.-1", "foo path").is_ok());
+        assert!(check_version("1.0.0", "foo path").is_ok());
 
         // Next major release is ERR
-        assert!(check_version("2.0.0", "foo path").is_err());
+        assert!(check_version("2.0.1", "foo path").is_err());
 
         // Next minor release is ERR
-        assert!(check_version("1.1.0", "foo path").is_err());
+        assert!(check_version("1.1.1", "foo path").is_err());
 
         // Next bugfix release is ERR (Change when we get to v1)
-        assert!(check_version("1.0.1", "foo path").is_err());
+        assert!(check_version("1.0.2", "foo path").is_err());
     }
 }
