@@ -17,7 +17,6 @@ pub enum MsgOut {
     CallLuaSilently(String),
     LuaEval(String),
     LuaEvalSilently(String),
-    Enque(Task),
     EnableMouse,
     DisableMouse,
     ToggleMouse,
@@ -34,4 +33,5 @@ pub enum MsgOut {
     PrintSelectionAndQuit,
     PrintResultAndQuit,
     PrintAppStateAndQuit,
+    Enqueue(Task),
 }
